MapMarkerIconModel class

Constructors

MapMarkerIconModel({required String iconPath, required double width, required double height})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
iconPath ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMapJs() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited